@@ -1,20 +1,17 @@
 // ADPersonPropertyView.m (this is -*- ObjC -*-)
 // 
-// \author: Bjrn Giesler <giesler@ira.uka.de>
+// Authors: Bjrn Giesler <giesler@ira.uka.de>
+//          Riccardo Mottola
 // 
 // Address View Framework for GNUstep
 // 
-// $Author: bjoern $
-// $Locker:  $
-// $Revision: 1.1.1.1 $
-// $Date: 2004/02/14 18:00:01 $
 
 /* system includes */
-#include <Foundation/Foundation.h>
+#import <Foundation/Foundation.h>
 
 /* my includes */
-#include "ADPersonView.h"
-#include "ADPersonPropertyView.h"
+#import "ADPersonView.h"
+#import "ADPersonPropertyView.h"
 
 @interface NSBezierPath (ADPersonPropertyExtensions)
 + (NSBezierPath *) bezierPathWithRoundedRectInRect:(NSRect)rect
@@ -276,6 +273,7 @@ static float _globalFontSize;
   [_delegate release];
   [_addImg release];
   [_chgImg release];
+  [super dealloc];
 }
 
 - (void) setDelegate: (id) delegate
@@ -314,7 +312,7 @@ static float _globalFontSize;
 
 - (BOOL) updatePersonWithMultiValueFromCell: (ADPersonPropertyCell*) cell
 {
-  NSString *key, *label, *identifier; id value; int i;
+  NSString *key, *label, *identifier; id value; NSInteger i;
   ADPropertyType type; ADMutableMultiValue *mv;
   NSMutableDictionary *dict;
 
@@ -410,8 +408,16 @@ static float _globalFontSize;
   switch(type)
     {
     case ADDateProperty:
-      value  = [NSDate dateWithString: value];
+      if([value isEmptyString])
+	 {
+	   if([_person valueForProperty: _property])
+	     return [_person removeValueForProperty: _property];
+	   else
+	     return NO;
+	 }
+      value = [NSCalendarDate dateWithNaturalLanguageString: value];
       if(!value) return NO;
+      return [_person setValue: value forProperty: _property];
 
     case ADStringProperty:
       if([value isEmptyString])
@@ -548,8 +554,8 @@ static float _globalFontSize;
       id cell;
 
       cell = [_cells objectAtIndex: _editingCellIndex];
-      [cell endEditing: _textObject];
       [cell setStringValue: [[[_textObject string] copy] autorelease]];
+      [cell endEditing: _textObject];
       
       if([[cell stringValue] isEmptyString])
 	{
@@ -593,7 +599,7 @@ static float _globalFontSize;
 
 - (BOOL) hasEditableCells
 {
-  int i;
+  NSUInteger i;
   for(i=0; i<[_cells count]; i++)
     if([[_cells objectAtIndex: i] isEditable])
       return YES;
@@ -605,7 +611,7 @@ static float _globalFontSize;
   return [_cells count] != 0;
 }
 
-- (void) beginEditingInCellAtIndex: (int) i
+- (void) beginEditingInCellAtIndex: (NSUInteger) i
 		 countingBackwards: (BOOL) backwards
 {
   while(![[_cells objectAtIndex: i] isEditable])
@@ -626,9 +632,9 @@ static float _globalFontSize;
   [self beginEditingInCellAtIndex: [_cells count]-1 countingBackwards: YES];
 }
 
-- (int) indexOfEditableCellWithDetails: (id) details
+- (NSUInteger) indexOfEditableCellWithDetails: (id) details
 {
-  int i;
+  NSUInteger i;
 
   for(i=0; i<[_cells count]; i++)
     {
@@ -647,7 +653,9 @@ static float _globalFontSize;
 
 - (NSString*) propertyForDragWithDetails: (id) details
 {
-  NSString *identifier; int index; ADMultiValue *mv;
+  NSString *identifier;
+  NSUInteger index;
+  ADMultiValue *mv;
   id value;
 
   if(!details &&
@@ -827,14 +835,14 @@ static float _globalFontSize;
 - (void) textDidEndEditing: (NSNotification*) aNotification
 {
   int textMovement = -1;
-  int cellIndex;
+  NSInteger cellIndex;
   id c;
   NSDictionary *dict = [aNotification userInfo];
   id details;
 
   c = [_cells objectAtIndex: _editingCellIndex];
-  [c endEditing: _textObject];
   [c setStringValue: [[[_textObject string] copy] autorelease]];
+  [c endEditing: _textObject];
 
   [self updatePersonWithValueFromCell: c];
   
