@@ -4,17 +4,9 @@
 // 
 // Address Book Framework for GNUstep
 // 
-// $Author: bjoern $
-// $Locker:  $
-// $Revision: 1.2 $
-// $Date: 2004/07/29 03:37:50 $
 
-/* system includes */
-/* (none) */
-
-/* my includes */
-#include "ADLocalAddressBook.h"
-#include "ADRecord.h"
+#import "ADLocalAddressBook.h"
+#import "ADRecord.h"
 
 static NSString *_localABDefLoc = @"~/GNUstep/Library/Addresses";
 static ADLocalAddressBook *_localAB = nil;
@@ -62,7 +54,7 @@ static ADLocalAddressBook *_localAB = nil;
       while((fname = [e nextObject]))
 	if([[fname pathExtension] isEqualToString: @"mfaddr"])
 	  next = MAX(next, [[fname stringByDeletingPathExtension] intValue]);
-      NSLog(@"New NEXTID is %d\n", next);
+      NSLog(@"New NEXTID is %lu\n", next);
     }
   next++;
 
@@ -389,6 +381,7 @@ static ADLocalAddressBook *_localAB = nil;
   [_unsaved release];
   [[NSNotificationCenter defaultCenter] removeObserver: self];
   [[NSDistributedNotificationCenter defaultCenter] removeObserver: self];
+  [super dealloc];
 }
 
 - (NSString*) location
