@@ -1,22 +1,11 @@
 // ADPublicAddressBook.h (this is -*- ObjC -*-)
 // 
-// \author: Bjrn Giesler <giesler@ira.uka.de>
+// Author: Bjrn Giesler <giesler@ira.uka.de>
 // 
 // Address Book Framework for GNUstep
 // 
-// $Author: bjoern $
-// $Locker:  $
-// $Revision: 1.1.1.1 $
-// $Date: 2004/02/14 18:00:02 $
 
-#ifndef ADPUBLICADDRESSBOOK_H
-#define ADPUBLICADDRESSBOOK_H
-
-/* system includes */
-/* (none) */
-
-/* my includes */
-#include "ADAddressBook.h"
+#import <Addresses/ADAddressBook.h>
 
 @interface ADPublicAddressBook: ADAddressBook
 {
@@ -33,4 +22,3 @@
 - (ADAddressBook*) addressBookForReadWriteAccessWithAuth: (id) auth;
 @end
 
-#endif /* ADPUBLICADDRESSBOOK_H */
