@@ -1,22 +1,16 @@
 // ADVCFConverter.h (this is -*- ObjC -*-)
 // 
-// \author: Bjrn Giesler <giesler@ira.uka.de>
+// Author: Bjrn Giesler <giesler@ira.uka.de>
 // 
 // Address Book Framework for GNUstep
 // 
-// $Author: bjoern $
-// $Locker:  $
-// $Revision: 1.1.1.1 $
-// $Date: 2004/02/14 18:00:02 $
 
-#ifndef ADVCFCONVERTER_H
-#define ADVCFCONVERTER_H
+#ifndef _ADVCFCONVERTER_H_
+#define _ADVCFCONVERTER_H_
 
-/* system includes */
-#include <Addresses/ADConverter.h>
 
-/* my includes */
-/* (none) */
+#import <Addresses/ADConverter.h>
+
 
 @interface ADVCFConverter: NSObject<ADInputConverting,ADOutputConverting>
 {
@@ -38,4 +32,4 @@
 - (NSString*) string;
 @end
 
-#endif /* ADVCFCONVERTER_H */
+#endif
